@@ -23,7 +23,7 @@ from robot.utils.asserts import assert_true
 from robot.utils.robottime import secs_to_timestr
 from robot.utils.robottypes import *
 from selenium import webdriver
-from selenium.common.exceptions import StaleElementReferenceException
+from selenium.common.exceptions import StaleElementReferenceException, TimeoutException
 
 
 class Error(RuntimeError):
@@ -199,7 +199,7 @@ class FacileToolkit2:
             lista_presente = BuiltIn().run_keyword_and_return_status("Wait Until Element is Visible", locator, timeout)
             if lista_presente:
                 self.select_from_list_random_index(locator=locator, start_index=start_index, end_index=end_index,
-                                                   timeout=timeout)
+                                                   timeout=timeout)\
 
     @keyword
     def i_land_on_page(self, url, timeout="60s"):
@@ -209,12 +209,15 @@ class FacileToolkit2:
         """
         self.set_selenium_library()
         try:
-            BuiltIn().run_keyword_and_ignore_error("wait_ajax")
             self.sl.log_location()
             self.sl.wait_until_location_contains(url, timeout)
             self.dom_is_loaded(timeout=timeout)
-        except:
-            self.sl.capture_page_screenshot(filename="EMBED")
+        except TimeoutException as e:
+            if "renderer" in str(e.msg).lower():
+                self.sl.driver.refresh()
+                self.sl.wait_until_location_contains(url, timeout)
+            else:
+                self.sl.capture_page_screenshot(filename="EMBED")
         finally:
             self.sl.log_location()
 
@@ -491,6 +494,7 @@ class FacileToolkit2:
         chrome_options.add_argument("--disable-gpu")
         chrome_options.add_argument("--disable-browser-side-navigation")
         chrome_options.add_experimental_option("excludeSwitches", ["enable-automation"])
+        chrome_options.set_capability("pageLoadStrategy", "eager")
         if headless:
             chrome_options.add_argument("--window-size=1920,960")
             chrome_options.headless = True
@@ -506,7 +510,6 @@ class FacileToolkit2:
         firefox_options.add_argument("--disable-gpu")
         firefox_options.add_argument("--disable-extensions")
         firefox_options.set_preference("browser.link.open_newwindow.restriction", 0)
-
         firefox_options.set_preference("browser.link.open_newwindow", 3)
         if headless:
             firefox_options.headless = True
@@ -527,6 +530,7 @@ class FacileToolkit2:
         chrome_options.add_argument("--disable-gpu")
         chrome_options.add_argument("--disable-browser-side-navigation")
         chrome_options.add_experimental_option("excludeSwitches", ["enable-automation"])
+        chrome_options.set_capability("pageLoadStrategy", "eager")
         if headless:
             chrome_options.headless = True
         return chrome_options
@@ -615,16 +619,26 @@ class FacileToolkit2:
 
     @keyword
     def screenshot_on_failure(self):
+        self._log_field_values()
         BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
         self.sl.log_location()
 
+    def _log_field_values(self):
+        try:
+            status, return_value = BuiltIn().run_keyword_and_ignore_error("execute_javascript", "return Array.from(document.querySelectorAll('select, input')).map(p=>{return {id: p.id, value:p.value, text:p.text}})")
+            if status == 'PASS' and return_value is not None:
+                Collections().log_list(list(return_value))
+        except:
+            pass
+
     @keyword
     def teardown_with_screenshot(self):
         self.set_selenium_library()
+        self._log_field_values()
         BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
         self.sl.log_location()
         self.sl.close_all_browsers()
-
+        
     def i_see_elements_label(self, *locators):
         self.set_selenium_library()
         for locator in locators:
